@@ -43,6 +43,12 @@ sub new {
         $self->$key( $options{$key} );
     }
 
+    $self->attributes( 'primary', ['as_set'] );
+    $self->attributes( 'mandatory', [ 'as_set', 'descr', 'tech_c', 'admin_c', 'mnt_by', 'changed', 'source' ] );
+    $self->attributes( 'optionnal', [ 'members', 'mbrs_by_ref', 'remarks', 'notify' ] );
+    $self->attributes( 'single', [ 'as_set', 'source' ] );
+    $self->attributes( 'multiple', [ 'descr', 'members', 'mbrs_by_ref', 'remarks', 'tech_c', 'admin_c', 'notify', 'mnt_by', 'changed' ] );
+
     return $self;
 }
 
@@ -62,8 +68,7 @@ with 'as-'.
 sub as_set {
     my ( $self, $as_set ) = @_;
 
-    $self->{as_set} = $as_set if defined $as_set;
-    return $self->{as_set};
+    return $self->_single_attribute_setget( 'as_set', $as_set );
 }
 
 =head2 B<descr( [$descr] )>
@@ -78,8 +83,8 @@ A short description related to the object's purpose.
 
 sub descr {
     my ( $self, $descr ) = @_;
-    push @{ $self->{descr} }, $descr if defined $descr;
-    return \@{ $self->{descr} };
+
+    return $self->_multiple_attribute_setget( 'descr', $descr );
 }
 
 =head2 B<members( [$member] )>
@@ -95,8 +100,8 @@ of AS Numbers, or other as-set names.
 
 sub members {
     my ( $self, $member ) = @_;
-    push @{ $self->{members} }, $member if defined $member;
-    return \@{ $self->{members} };
+
+    return $self->_multiple_attribute_setget( 'member', $member );
 }
 
 =head2 B<mbrs_by_ref( [$mbr] )>
@@ -121,8 +126,8 @@ defined explicitly by the members attribute.
 
 sub mbrs_by_ref {
     my ( $self, $mbr ) = @_;
-    push @{ $self->{mbrs_by_ref} }, $mbr if defined $mbr;
-    return \@{ $self->{mbrs_by_ref} };
+
+    return $self->_multiple_attribute_setget( 'mbr', $mbr );
 }
 
 =head2 B<remarks( [$remark] )>
@@ -138,8 +143,8 @@ May include a URL or email address.
 
 sub remarks {
     my ( $self, $remark ) = @_;
-    push @{ $self->{remarks} }, $remark if defined $remark;
-    return \@{ $self->{remarks} };
+
+    return $self->_multiple_attribute_setget( 'remarks', $remark );
 }
 
 =head2 B<tech_c( [$tech_c] )>
@@ -160,8 +165,8 @@ physically located at the site of the network.
 
 sub tech_c {
     my ( $self, $tech_c ) = @_;
-    push @{ $self->{tech_c} }, $tech_c if defined $tech_c;
-    return \@{ $self->{tech_c} };
+
+    return $self->_multiple_attribute_setget( 'tech_c', $tech_c );
 }
 
 =head2 B<admin_c( [$admin_c] )>
@@ -180,8 +185,8 @@ located at the site of the network.
 
 sub admin_c {
     my ( $self, $admin_c ) = @_;
-    push @{ $self->{admin_c} }, $admin_c if defined $admin_c;
-    return \@{ $self->{admin_c} };
+
+    return $self->_multiple_attribute_setget( 'admin_c', $admin_c );
 }
 
 =head2 B<notify( [$notify] )>
@@ -197,8 +202,8 @@ sent.
 
 sub notify {
     my ( $self, $notify ) = @_;
-    push @{ $self->{notify} }, $notify if defined $notify;
-    return \@{ $self->{notify} };
+
+    return $self->_multiple_attribute_setget( 'notify', $notify );
 }
 
 =head2 B<mnt_by( [$mnt] )>
@@ -218,8 +223,8 @@ object will be able to change details.
 
 sub mnt_by {
     my ( $self, $mnt ) = @_;
-    push @{ $self->{mnt_by} }, $mnt if defined $mnt;
-    return \@{ $self->{mnt_by} };
+
+    return $self->_multiple_attribute_setget( 'mnt', $mnt );
 }
 
 =head2 B<changed( [$changed] )>
@@ -241,8 +246,8 @@ format using one of the following two formats: YYYYMMDD or YYMMDD.
 
 sub changed {
     my ( $self, $changed ) = @_;
-    push @{ $self->{changed} }, $changed if defined $changed;
-    return \@{ $self->{changed} };
+
+    return $self->_multiple_attribute_setget( 'changed', $changed );
 }
 
 =head2 B<source( [$source] )>
@@ -256,8 +261,8 @@ The database where the object is registered.
 
 sub source {
     my ( $self, $source ) = @_;
-    $self->{source} = $source if defined $source;
-    return $self->{source};
+
+    return $self->_single_attribute_setget( 'source', $source );
 }
 
 1;
