@@ -49,6 +49,12 @@ sub new {
         $self->$key( $options{$key} );
     }
 
+    $self->attributes( 'primary', ['rtr_set'] );
+    $self->attributes( 'mandatory', [ 'rtr_set', 'descr', 'tech_c', 'admin_c', 'mnt_by', 'changed', 'source' ] );
+    $self->attributes( 'optionnal', [ 'members', 'mbrs_by_ref', 'remarks', 'notify' ] );
+    $self->attributes( 'single', [ 'rtr_set', 'source' ] );
+    $self->attributes( 'multiple', [ 'descr', 'tech_c', 'admin_c', 'mnt_by', 'changed', 'members', 'mbrs_by_ref', 'remarks', 'notify' ] );
+
     return $self;
 }
 
@@ -61,8 +67,8 @@ Accepts an optional rtr_set, always return the current rtr_set.
 
 sub rtr_set {
     my ( $self, $rtr_set ) = @_;
-    $self->{rtr_set} = $rtr_set if defined $rtr_set;
-    return $self->{rtr_set};
+
+    return $self->_single_attribute_setget( 'rtr_set', $rtr_set );
 }
 
 =head2 B<descr( [$descr] )>
@@ -75,8 +81,8 @@ always return the current descr array.
 
 sub descr {
     my ( $self, $descr ) = @_;
-    push @{ $self->{descr} }, $descr if defined $descr;
-    return \@{ $self->{descr} };
+
+    return $self->_multiple_attribute_setget( 'descr', $descr );
 }
 
 =head2 B<members( [$member] )>
@@ -89,8 +95,8 @@ always return the current members array.
 
 sub members {
     my ( $self, $member ) = @_;
-    push @{ $self->{members} }, $member if defined $member;
-    return \@{ $self->{members} };
+
+    return $self->_multiple_attribute_setget( 'members', $member );
 }
 
 =head2 B<mbrs_by_ref( [$mbrs_by_ref] )>
@@ -103,8 +109,8 @@ always return the current mbrs_by_ref array.
 
 sub mbrs_by_ref {
     my ( $self, $mbrs_by_ref ) = @_;
-    push @{ $self->{mbrs_by_ref} }, $mbrs_by_ref if defined $mbrs_by_ref;
-    return \@{ $self->{mbrs_by_ref} };
+
+    return $self->_multiple_attribute_setget( 'mbrs_by_ref', $mbrs_by_ref );
 }
 
 =head2 B<remarks( [$remark] )>
@@ -117,8 +123,8 @@ always return the current remarks array.
 
 sub remarks {
     my ( $self, $remark ) = @_;
-    push @{ $self->{remarks} }, $remark if defined $remark;
-    return \@{ $self->{remarks} };
+
+    return $self->_multiple_attribute_setget( 'remarks', $remark );
 }
 
 =head2 B<tech_c( [$contact] )>
@@ -131,8 +137,8 @@ always return the current tech_c array.
 
 sub tech_c {
     my ( $self, $contact ) = @_;
-    push @{ $self->{tech_c} }, $contact if defined $contact;
-    return \@{ $self->{tech_c} };
+
+    return $self->_multiple_attribute_setget( 'tech_c', $contact );
 }
 
 =head2 B<admin_c( [$contact] )>
@@ -145,8 +151,8 @@ always return the current admin_c array.
 
 sub admin_c {
     my ( $self, $contact ) = @_;
-    push @{ $self->{admin_c} }, $contact if defined $contact;
-    return \@{ $self->{admin_c} };
+
+    return $self->_multiple_attribute_setget( 'admin_c', $contact );
 }
 
 =head2 B<notify( [$notify] )>
@@ -159,8 +165,8 @@ always return the current notify array.
 
 sub notify {
     my ( $self, $notify ) = @_;
-    push @{ $self->{notify} }, $notify if defined $notify;
-    return \@{ $self->{notify} };
+
+    return $self->_multiple_attribute_setget( 'notify', $notify );
 }
 
 =head2 B<mnt_by( [$mnt_by])>
@@ -173,8 +179,8 @@ always return the current mnt_by array.
 
 sub mnt_by {
     my ( $self, $mnt_by ) = @_;
-    push @{ $self->{mnt_by} }, $mnt_by if defined $mnt_by;
-    return \@{ $self->{mnt_by} };
+
+    return $self->_multiple_attribute_setget( 'mnt_by', $mnt_by );
 }
 
 =head2 B<changed( [$changed] )>
@@ -187,8 +193,8 @@ always return the current changed array.
 
 sub changed {
     my ( $self, $changed ) = @_;
-    push @{ $self->{changed} }, $changed if defined $changed;
-    return \@{ $self->{changed} };
+
+    return $self->_multiple_attribute_setget( 'changed', $changed );
 }
 
 =head2 B<source( [$source] )>
@@ -200,8 +206,8 @@ Accepts an optional source, always return the current source.
 
 sub source {
     my ( $self, $source ) = @_;
-    $self->{source} = $source if defined $source;
-    return $self->{source};
+
+    return $self->_single_attribute_setget( 'source', $source );
 }
 
 =head2 B<mp_members( [$mp_member] )>
@@ -225,8 +231,8 @@ Explicitly lists IPv4 or IPv6 'members' of the rtr-set can be:
 
 sub mp_members {
     my ( $self, $mp_member ) = @_;
-    push @{ $self->{mp_members} }, $mp_member if defined $mp_member;
-    return \@{ $self->{mp_members} };
+
+    return $self->_multiple_attribute_setget( 'mp_members', $mp_member );
 }
 
 1;
